from __future__ import unicode_literals
from __future__ import absolute_import
from ...models import Model


class Brand(Model):
    pass


class Campaign(Model):
    pass


class Rule(Model):
    pass


class TrafficSource(Model):
    pass
